==> chromium_89.0.4389.114.orig.tar.xz: chromium-89.0.4389.114/chrome/browser/resources/pdf/pdf_viewer_wrapper.js <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

export {BrowserApi, ZoomBehavior} from './browser_api.js';
export {FittingType, SaveRequestType} from './constants.js';
export {PluginController} from './controller.js';
export {ViewerDocumentOutlineElement} from './elements/viewer-document-outline.js';
export {ViewerDownloadControlsElement} from './elements/viewer-download-controls.js';
export {ViewerPdfSidenavElement} from './elements/viewer-pdf-sidenav.js';
export {ViewerPdfToolbarNewElement} from './elements/viewer-pdf-toolbar-new.js';
export {ViewerPropertiesDialogElement} from './elements/viewer-properties-dialog.js';
export {ViewerThumbnailBarElement} from './elements/viewer-thumbnail-bar.js';
export {PAINTED_ATTRIBUTE, ViewerThumbnailElement} from './elements/viewer-thumbnail.js';
export {GestureDetector, PinchEventDetail} from './gesture_detector.js';
export {record, recordFitTo, recordTwoUpViewEnabled, recordZoomAction, resetForTesting, UserAction} from './metrics.js';
export {NavigatorDelegate, PdfNavigator, WindowOpenDisposition} from './navigator.js';
export {OpenPdfParamsParser} from './open_pdf_params_parser.js';
export {PDFScriptingAPI} from './pdf_scripting_api.js';
export {getFilenameFromURL, PDFViewerElement} from './pdf_viewer.js';
export {shouldIgnoreKeyEvents} from './pdf_viewer_utils.js';
export {ToolbarManager} from './toolbar_manager.js';
export {LayoutOptions, PAGE_SHADOW, Viewport} from './viewport.js';
export {ZoomManager} from './zoom_manager.js';

==> chromium-93.0.4535.3.tar.xz: chromium-93.0.4535.3/chrome/browser/resources/pdf/pdf_viewer_wrapper.js <==
// Copyright 2021 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

export {BrowserApi, ZoomBehavior} from './browser_api.js';
export {FittingType, SaveRequestType} from './constants.js';
export {PluginController} from './controller.js';
export {ViewerBookmarkElement} from './elements/viewer-bookmark.js';
export {ViewerDocumentOutlineElement} from './elements/viewer-document-outline.js';
export {ViewerDownloadControlsElement} from './elements/viewer-download-controls.js';
export {ViewerPageSelectorElement} from './elements/viewer-page-selector.js';
export {ViewerPasswordDialogElement} from './elements/viewer-password-dialog.js';
export {ViewerPdfSidenavElement} from './elements/viewer-pdf-sidenav.js';
export {ViewerPropertiesDialogElement} from './elements/viewer-properties-dialog.js';
export {ViewerThumbnailBarElement} from './elements/viewer-thumbnail-bar.js';
export {PAINTED_ATTRIBUTE, ViewerThumbnailElement} from './elements/viewer-thumbnail.js';
export {ViewerToolbarElement} from './elements/viewer-toolbar.js';
export {GestureDetector, PinchEventDetail} from './gesture_detector.js';
export {record, recordFitTo, resetForTesting, UserAction} from './metrics.js';
export {NavigatorDelegate, PdfNavigator, WindowOpenDisposition} from './navigator.js';
export {OpenPdfParamsParser} from './open_pdf_params_parser.js';
export {PDFScriptingAPI} from './pdf_scripting_api.js';
export {getFilenameFromURL, PDFViewerElement} from './pdf_viewer.js';
export {shouldIgnoreKeyEvents} from './pdf_viewer_utils.js';
export {LayoutOptions, PAGE_SHADOW, Viewport} from './viewport.js';
export {ZoomManager} from './zoom_manager.js';

// <if expr="enable_ink">
export {ViewerToolbarDropdownElement} from './elements/viewer-toolbar-dropdown.js';
// </if>
